@@ -10,6 +10,6 @@ import (
 func TestCanLoadGrammar(t *testing.T) {
 	language := tree_sitter.NewLanguage(tree_sitter_javascript.Language())
 	if language == nil {
-		t.Errorf("Error loading Javascript grammar")
+		t.Errorf("Error loading JavaScript grammar")
 	}
 }
